@@ -4,7 +4,7 @@
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
-#   the Free Software Foundation; either version 2 of the License, or
+#   the Free Software Foundation; either version 3 of the License, or
 #   (at your option) any later version.
 #
 #   This program is distributed in the hope that it will be useful,
@@ -13,8 +13,7 @@
 #   GNU General Public License for more details.
 #
 #   You should have received a copy of the GNU General Public License
-#   along with this program; if not, write to the Free Software
-#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#   along with this program; if not, see <http://www.gnu.org/licenses/>.
 #
 import gnomecanvas
 import gcompris
@@ -30,11 +29,11 @@ import math
 
 # Background screens
 backgrounds = [
-  "images/scenery2_background.png",
-  "images/scenery3_background.png",
-  "images/scenery4_background.png",
-  "images/scenery5_background.png",
-  "images/scenery6_background.png"
+  "opt/scenery2_background.png",
+  "opt/scenery3_background.png",
+  "opt/scenery4_background.png",
+  "opt/scenery5_background.png",
+  "opt/scenery6_background.png"
 ]
 
 MAX_USERS_AT_ONCE = 10
@@ -45,6 +44,7 @@ class Gcompris_login:
 
   def __init__(self, gcomprisBoard):
     self.gcomprisBoard = gcomprisBoard
+    self.entry = []
 
     self.gcomprisBoard.disable_im_context = True
 
@@ -187,9 +187,9 @@ class Gcompris_login:
     # There is a problem with GTK widgets, they are not covered by the help
     # We hide/show them here
     if(pause):
-      self.entry.hide()
+      if self.entry: self.entry.hide()
     else:
-      self.entryt.show()
+      if self.entry: self.entry.show()
 
 
   def set_level(self, level):
